pub enum Msc4108IntentData {
Login,
Reciprocate {
server_name: String,
},
}Expand description
The intent-specific data for the QR code.
The QR code login mechanism supports both, the new device, as well as the existing device to display the QR code.
Depending on which device is displaying the QR code, additional data will be attached to the QR code.
Variants
Login
Enum variant for the case where the new device is displaying the QR code.
Reciprocate
Enum variant for the case where the existing device is displaying the QR code.