pub struct QrCodeData { /* private fields */ }Expand description
Data for the QR code login mechanism.
The QrCodeData can be serialized and encoded as a QR code or it can be
decoded from a QR code.
Implementations
Sourceimpl QrCodeData
impl QrCodeData
Sourcepub fn new_msc4108(
public_key: Curve25519PublicKey,
rendezvous_url: Url,
intent_data: Msc4108IntentData,
) -> Self
pub fn new_msc4108( public_key: Curve25519PublicKey, rendezvous_url: Url, intent_data: Msc4108IntentData, ) -> Self
Create a new QrCodeData object which conforms to the data format
specified in MSC4108.
Sourcepub fn new_msc4388(
public_key: Curve25519PublicKey,
rendezvous_id: String,
base_url: Url,
intent: QrCodeIntent,
) -> Self
pub fn new_msc4388( public_key: Curve25519PublicKey, rendezvous_id: String, base_url: Url, intent: QrCodeIntent, ) -> Self
Create a new QrCodeData object which conforms to the data format
specified in MSC4388.
Sourcepub fn from_bytes(bytes: &[u8]) -> Result<Self, LoginQrCodeDecodeError>
pub fn from_bytes(bytes: &[u8]) -> Result<Self, LoginQrCodeDecodeError>
Attempt to decode a slice of bytes into a QrCodeData object.
The slice of bytes would generally be returned by a QR code decoder.
Sourcepub fn to_bytes(&self) -> Vec<u8> ⓘ
pub fn to_bytes(&self) -> Vec<u8> ⓘ
Encode the QrCodeData into a list of bytes.
The list of bytes can be used by a QR code generator to create an image containing a QR code.
Sourcepub fn from_base64(data: &str) -> Result<Self, LoginQrCodeDecodeError>
pub fn from_base64(data: &str) -> Result<Self, LoginQrCodeDecodeError>
Attempt to decode a base64 encoded string into a QrCodeData object.
Sourcepub fn to_base64(&self) -> String
pub fn to_base64(&self) -> String
Encode the QrCodeData into a base64 encoded string.
Sourcepub fn public_key(&self) -> Curve25519PublicKey
pub fn public_key(&self) -> Curve25519PublicKey
The ephemeral Curve25519 public key. Can be used to establish a shared secret using the Diffie-Hellman key agreement.
Sourcepub fn intent(&self) -> QrCodeIntent
pub fn intent(&self) -> QrCodeIntent
Get the QrCodeIntent of this QrCodeData object.
This tells us if the creator of the QR code wants to log in or if they want to log another device in.
Sourcepub fn intent_data(&self) -> QrCodeIntentData<'_>
pub fn intent_data(&self) -> QrCodeIntentData<'_>
The intent-specific data for the QR code.