pub enum QrCodeIntent {
Login,
Reciprocate,
}Expand description
The intent of the device that generated/displayed the QR code.
The QR code login mechanism supports both, the new device, as well as the existing device to display the QR code.
The different intents have an explicit one-byte identifier which gets added to the QR code data.
Variants
Login
Enum variant for the case where the new device is displaying the QR code.
Reciprocate
Enum variant for the case where the existing device is displaying the QR code.